/* $Id: mesh.h,v 1.3 1998/02/04 16:47:24 svmcguir Exp $ */

typedef struct{
  /* meshData structure.
   *
   * Contains an optionData structure and other data for performing the
   * stochastic mesh algorithm.
   *
   * meshPaths			The first meshPath paths in the optionData
   *				structure will be used for the mesh estimate.
   *				The remaining paths only for the path estimate.
   *
   * valueIfHeld[time][path]	The value expected to be obtained by holding
   *				the option instead of exercising it.
   *
   * value[time][path]		The value of the option.  The greater of the
   *				value from holding and that from exercising.
   *
   * option			An optionData structure holding the information
   *				about the option payoffs and information about
   *				the underlier paths upon which the other data
   *				is derived.
   */

   int meshPaths;
   double **valueIfHeld;
   double **newValueIfHeld;
   double **value;
   double **newValue;
   double ***weights;
   optionData option;
}meshData;

void meshDataAllocate(meshData *md);
void meshSetFinalValue(meshData *md);
double meshCalculateEuropean(meshData *md); 
double meshWeight(meshData *md, int time, int toPath, int fromPath);
double meshValueIfHeld(meshData *md, int time, int path);
void meshDataFill(meshData *md);
double meshMeshEstimate(meshData *md);
double meshPathEstimate(meshData *md);
double meshControlledPathEstimate(meshData *md);

